@@ -8,9 +8,11 @@ import pylatex
 import matplotlib
 #from pylatex.utils import italic, bold
 from datetime import date
-# from pylatex import Document, Section, Subsection, Tabular, Math, TikZ, Axis, \
-#     Plot, Figure, Matrix, Alignat, Quantity, MiniPage, LargeText, LineBreak, \
-#     MediumText, PageStyle, Head, simple_page_number, Foot
+from pylatex import Document, PageStyle, Head, LineBreak, simple_page_number,\
+Foot, MiniPage, LargeText, MediumText, Section, Subsection, Math, Alignat
+#, , , Tabular, , TikZ, Axis, \
+#     Plot, Figure, Matrix, , Quantity, , , \
+#     
 # import matplotlib.image as mpimg
 import math
 import numpy as np
